/*
 rev 1.3 04/04/2014
 Insettoteca 
 http://frameyun.local/sd/index.php
 */

#include <Bridge.h>
#include <YunServer.h>
#include <YunClient.h>
#include <Process.h>
#include <dht.h>
#include <Servo.h>

#define DHT22_PIN 13

// Listen on default port 5555, the webserver on the Yun
// will forward there all the HTTP requests for us.
YunServer server;
String readString; 
dht DHT;
Servo motore;

// Variabili
int cicli = 0;           //Contatore del numero di loop
int timePumpOn = 400;      //Contatore per l'autospegnimento della pompa

// Costanti
int oLight = 3;
int oVent  = 5;          //Porta del ventilatore
int oPump  = 4;          //Porta della pompa
int oHeat  = 2;          //Porta del riscaldatore
int maxPumpOn = 400;     //Tempo massimo di accensione della pompa 200 cicli
int posWebcam  = 90;     //Posizione della webcam centrale


// ---- SETUP ----
void setup() {
  
//  Serial.begin(9600);
//  Serial.println("--INSETTOTECA V1.1--");
  
  motore.attach(10);       // attaches the servo on pin 9 to the servo object 
  
  // Bridge startup
  pinMode(oLight, OUTPUT);
  pinMode(oVent, OUTPUT);
  pinMode(oPump, OUTPUT);  
  pinMode(oHeat, OUTPUT);
  
  //Modalità di avvio
  digitalWrite(oPump, HIGH);
  digitalWrite(oHeat, HIGH);
  
  Bridge.begin();
  //digitalWrite(13, HIGH);
 
  //Acquisizione stato porte
  //Process linuxBootUp;
 
  // Listen for incoming connection only from localhost (Linino)
  // (no one from the external network could connect)
  server.listenOnLocalhost();
  server.begin();
  
}

// ------ LOOP ----- 
void loop() {
  // Get clients coming from server
  YunClient client = server.accept();
  Process linux;
  String testo;
  
  //-- GESTIONE AUTOMATICA --
  if(timePumpOn <= 0){
    //Spegniamo la pompa dopo un massimo di tempo
    digitalWrite(oPump, HIGH);
    linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,0,3,datetime('now','localtime') );\" ");
    delay(10);
    timePumpOn = maxPumpOn;
  }
  
  
  //-- GESTIONE RICHIESTE DA PAGINA WEB --
  if (client) {
        
    digitalWrite(13, HIGH);
    // read the command
    String command = client.readString();
    command.trim();        //kill whitespace
//    Serial.println(command); //Visualizza sul monitor seriale i comandi inviati

    if (command == "ledon") {
       digitalWrite(13, HIGH);
    }
    else if (command == "ledoff") {
       digitalWrite(13, LOW);
    }
    
    //Gestione Luce
    if (command == "lightON") {
       digitalWrite(oLight, LOW);
       client.print(" <button width=50px height=20px style='background:green'> ACCESA </button>");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,1,1,datetime('now','localtime') );\" ");  
    }
    else if (command == "lightOFF") {
       digitalWrite(oLight, HIGH);
       client.print(" <button width=50px height=20px style='background:red'> SPENTA </button> ");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,0,1,datetime('now','localtime') );\" ");  
    }
    
        //Gestione Ventola
    if (command == "ventON") {
       digitalWrite(oVent, LOW);
       client.print(" <button width=50px height=20px style='background:green'> ACCESA </button>");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,1,2,datetime('now','localtime') );\" ");
    }
    else if (command == "ventOFF") {
       digitalWrite(oVent, HIGH);
       client.print(" <button width=50px height=20px style='background:red'> SPENTA </button> ");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,0,2,datetime('now','localtime') );\" "); 
    }
    
    //Gestione pompa
    if (command == "pumpON") {
       digitalWrite(oPump, LOW);
       timePumpOn = maxPumpOn - 1;
       client.print(" <button width=50px height=20px style='background:green'> ACCESA </button>");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,1,3,datetime('now','localtime') );\" ");
    }
    else if (command == "pumpOFF") {
       digitalWrite(oPump, HIGH);
       timePumpOn = maxPumpOn;
       client.print(" <button width=50px height=20px style='background:red'> SPENTA </button> ");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,0,3,datetime('now','localtime') );\" "); 
    }
    
    //Gestione riscaldamento
    if (command == "heatON") {
       digitalWrite(oHeat, LOW);
       client.print(" <button width=50px height=20px style='background:green'> ACCESA </button>");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,1,4,datetime('now','localtime') );\" ");
    }
    else if (command == "heatOFF") {
       digitalWrite(oHeat, HIGH);
       client.print(" <button width=50px height=20px style='background:red'> SPENTA </button> ");
       linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO output VALUES (null,0,4,datetime('now','localtime') );\" "); 
    }
    
    //Comando della rotazione  della webcam
    if (command == "webcamDx") {
      if (posWebcam <= 160 ){
          posWebcam += 15;
      }
      String testo = String(posWebcam);
       client.print(" <button width=50px height=20px style='background:blue'> "+testo+"</button> ");
       //Fai spostare la webcam a Destra
       motore.write(posWebcam);
    }else if (command == "webcamSx") {
       if (posWebcam >= 15){
         posWebcam -= 15;
       }
       String testo = String(posWebcam);
       client.print(" <button width=50px height=20px style='background:blue'> "+testo+" </button> ");
       motore.write(posWebcam);
    }
  
    // Close connection and free resources.
    client.stop();
  }
  
  // -- GESTIONE STATO --

  //Sonda temperatura ed umidita  
  if(cicli > 5000){ 

    // READ DATA
    //Serial.print("DHT22, \t");
    int chk = DHT.read22(DHT22_PIN);
    //switch (chk)
    //{
    //  case DHTLIB_OK:  
 // 		Serial.print("OK,\t"); 
 // 		break;
 //     case DHTLIB_ERROR_CHECKSUM: 
 // 		Serial.print("Checksum error,\t"); 
 // 		break;
 //     case DHTLIB_ERROR_TIMEOUT: 
 // 		Serial.print("Time out error,\t"); 
 // 		break;
 //     default: 
 // 		Serial.print("Unknown error,\t"); 
 // 		break;
 //   }
    
    // Display data
    String temp = String(DHT.temperature);
    String umid = String(DHT.humidity);
    
    linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO input VALUES (null,\""+temp+"\",1,datetime('now','localtime') );\" ");
    delay(10);
    linux.runShellCommand("sqlite3 /mnt/sd/arduino/db/data.db \"INSERT INTO input VALUES (null,\""+umid+"\",2,datetime('now','localtime') );\" ");
    delay(10);
    
    cicli = 0;
  }
  

  //-- CHISURA ED AVANZAMENTO --
  
  //Avanzamento timer disattivazione pompa
  if ( timePumpOn < maxPumpOn){
    timePumpOn -= 1;
  }
  
  
  //Chiusura e avanzamento del ciclo  
  cicli += 1;
  delay(5); // Poll every 10ms
}
